-- <!DOCTYPE ADA>
-- <ADA>

--------------------------------------------------------------------------------
-- <PROLOGUE>
-- <UNIT>        C_String_Utilities
--
-- <DESCRIPTION> This package exports a type which is the Ada representation
--               of a C string as well as routines to convert from a C string 
--               to an Ada string.
--
-- <HISTORY>
--
-- <ORIGIN>
-- <AUTHOR>      Gerardo A. Colon
-- <DATE>        19 September 1990
--
-- <COMPANY>     Science Applications International Corporation
-- <ADDRESS>     311 Park Place Boulevard, Suite 360
-- <ADDRESS>     Clearwater, Florida 34619
--
-- <REMARK>      Developed for the STARS program under task S40.
-- </ORIGIN>
--
-- </HISTORY>
--
-- <NOTES>       Dependencies =>
--                 ( Operating_System => AIX  ,
--                   Compiler         => None ,
--                   Device           => None ) ;
--
-- </PROLOGUE>
--------------------------------------------------------------------------------

with Interface_Definitions ;

pragma Elaborate ( Interface_Definitions ) ;

pragma Page ;

--------------------------------------------------------------------------------
-- package C_String_Utilities (body).
--------------------------------------------------------------------------------

package body C_String_Utilities is

--------------------------------------------------------------------------------
-- Local Subprograms.
--------------------------------------------------------------------------------

  function Strlen 
    ( S : in String_Pointer ) return Interface_Definitions.Interface_Unsigned ;
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        Strlen
--
-- <DESCRIPTION> This function returns the length of the string pointed by 
--               the string pointer given by S.
--
-- <EXCEPTIONS>  None.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
  pragma Interface ( C , Strlen ) ;

--------------------------------------------------------------------------------
-- External Subprograms.
--------------------------------------------------------------------------------

  function String_Of ( The_C_String : in String_Pointer ) return String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        String_Of
--
-- <DESCRIPTION> This function returns the string pointed by the pointer given
--               by The_Pointer.
--
-- <EXCEPTIONS>  None.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
    The_String : String ( 1 .. Integer ( Strlen ( The_C_String ) ) ) ;
    for The_String use at The_C_String ;
  begin -- String_Of
    return The_String ;
  end String_Of ;

end C_String_Utilities ;

-- </ADA>
