-- <!DOCTYPE ADA>
-- <ADA>

--------------------------------------------------------------------------------
-- <PROLOGUE>
-- <UNIT>        Interface_Definitions
--
-- <DESCRIPTION> This package provides type definitions for the Ada represen-
--               tation of some C types.  This package is used by other packages
--               which interface to C routines.
--
-- <HISTORY>
--
-- <ORIGIN>
-- <AUTHOR>      Gerardo A. Colon
-- <DATE>        19 September 1990
--
-- <COMPANY>     Science Applications International Corporation
-- <ADDRESS>     311 Park Place Boulevard, Suite 360
-- <ADDRESS>     Clearwater, Florida 34619
--
-- <REMARK>      Developed for the STARS program under task S40.
-- </ORIGIN>
--
-- </HISTORY>
--
-- <NOTES>       Dependencies =>
--                 ( Operating_System => None            ,
--                   Compiler         => Host C Compiler ,
--                   Device           => None            ) ;
--
-- </PROLOGUE>
--------------------------------------------------------------------------------

with System ;

pragma Page ;

--------------------------------------------------------------------------------
-- package Interface_Definitions (specification).
--------------------------------------------------------------------------------

package Interface_Definitions is

  Integer_First       : constant := (-2**31) ;
--
-- This constant defines the lower bound value for an integer.
--

  Integer_Last        : constant := (2**31-1) ;
--
-- This constant defines the upper bound value for an integer.
--

  Short_Integer_First : constant := (-2**15) ;
--
-- This constant defines the lower bound value for a short integer.
--

  Short_Integer_Last  : constant := (2**15-1) ;
--
-- This constant defines the upper bound value for a short integer.
--

  type Interface_Integer is range Integer_First .. Integer_Last ;
--
-- This type defines an integer which is compatible with a C int type.
--

  type Interface_Unsigned is range 0 .. Integer_Last ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned.
--

  type Interface_Ulong is range 0 .. Integer_Last ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned long.
--

  type Interface_Ushort is range 0 .. Short_Integer_Last ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned short.
--

  type Interface_Long is range Integer_First .. Integer_Last ;
--
-- This type defines an integer which is compatible with the C type long.
--

  type Interface_Short is range Short_Integer_First .. Short_Integer_Last ;
--
-- This type defines an integer which is compatible with the C type long.
--

  subtype Integer_Pointer is System.Address ;
--
-- This type defines a reference to the type Interface_Integer.  This is 
-- necessary since C functions only take parameters of mode "in".
--

end Interface_Definitions ;

-- </ADA>
