-- <!DOCTYPE ADA>
-- <ADA>

--------------------------------------------------------------------------------
-- <PROLOGUE>
-- <UNIT>        OSI_Exceptions
--
-- <DESCRIPTION> This package exports the exceptions used throughout the OSI
--               packages.
--
-- <HISTORY>
--
-- <ORIGIN>
-- <AUTHOR>      Gerardo A. Colon
-- <DATE>        11 July 1990
--
-- <COMPANY>     Science Applications International Corporation
-- <ADDRESS>     311 Park Place Boulevard, Suite 360
-- <ADDRESS>     Clearwater, Florida 34619
--
-- <REMARK>      Developed for the STARS program under task S40.
-- </ORIGIN>
--
-- </HISTORY>
--
-- <NOTES>       Dependencies =>
--                 ( Operating_System => None ,
--                   Compiler         => None ,
--                   Device           => None ) ;
--
-- </PROLOGUE>
--------------------------------------------------------------------------------

pragma Page ;

--------------------------------------------------------------------------------
-- package OSI_Exceptions (specification).
--------------------------------------------------------------------------------

package OSI_Exceptions is

  Bad_File_Descriptor              : exception ;
  Directory_Not_Empty              : exception ;
  Exec_Format_Error                : exception ;
  File_Exists                      : exception ;
  Filename_Too_Long                : exception ;
  Invalid_Argument                 : exception ;
  Is_A_Directory                   : exception ;
  No_Space_Left_On_Device          : exception ;
  No_Such_File_Or_Directory        : exception ;
  Not_A_Directory                  : exception ;
  Not_Enough_Space                 : exception ;
  Permission_Denied                : exception ;
  Read_Only_File_System            : exception ;
  Resource_Temporarily_Unavailable : exception ;
  Too_Many_Links                   : exception ;
  Too_Many_Open_Files              : exception ;
  Too_Many_Open_Files_In_System    : exception ;
--
-- The exception Bad_File_Descriptor is raised when a file descriptor 
-- referred to no open file.
--
-- The exception Directory_Not_Empty is raised when a directory contains 
-- more than the dot and dot-dot entries and it is expected to be empty.
--
-- The exception Exec_Format_Error is raised when a request is made to execute
-- a file which is not in the format required by the implementation for 
-- executable files.
--
-- The exception File_Exists is raised when an existing file is specified in an
-- inappropriate context.
--
-- The exception Filename_Too_Long is raised when the size of a pathname or
-- the size of a filename exceeds its limit.
--
-- The exception Invalid_Argument is raised when some invalid argument is 
-- supplied.
--
-- The exception Is_A_Directory is raised when an attempt is made to open a 
-- directory with write mode specified.
--
-- The exception No_Space_Left_On_Device is raised when during a write function
-- on a regular file, or when extending a directory, there is no more free 
-- space left on the device.
--
-- The exception No_Such_File_Or_Directory is raised when a component of a 
-- specified pathname does not exist, or the pathname is an empty string.
--
-- The exception Not_A_Directory is raised when a component of a pathname 
-- exists but is not a directory, and a directory is expected.
--
-- The exception Not_Enough_Space is raised when a new process image requires 
-- more memory than is allowed by the hardware or what is imposed by 
-- memory-management constraints.
--
-- The exception Permission_Denied is raised when an attempt is made to access
-- a file in a way forbidden by its file access permissions.
--
-- The exception Read_Only_File_System is raised when an attempt is made to
-- modify a file or a directory in a file system that is read-only.
--
-- The exception Resource_Temporarily_Unavailable is raised when a requested 
-- resource is unavailable at the time of the request.  This is temporary, 
-- a call to the same routine later on can be successfully completed.
--
-- The exception Too_Many_Links is raised when an attempt is made to have the
-- link count to a file exceed its maximum.
--
-- The exception Too_Many_Open_Files is raised when an attempt is made by a 
-- process to open more than the maximum allowed file descriptors for a 
-- process.
--
-- The exception Too_Many_Open_Files_In_System is raised when too many files
-- are open in the system.
--

--------------------------------------------------------------------------------
-- Implementation defined exceptions.
--------------------------------------------------------------------------------

  Filename_Syntax_Error            : exception ;
  Host_Error                       : exception ;
--
-- The exception Filename_Syntax_Error is raised when a file name contains one 
-- or more characters not supported by the application.
--
-- The exception Host_Error is raised when an exceptional condition is raised
-- by a system dependent operation which cannot be mapped to any other exception
-- defined by this package.
--

end OSI_Exceptions ;

-- </ADA>
