-- <!DOCTYPE ADA>
-- <ADA>

--------------------------------------------------------------------------------
-- <PROLOGUE>
-- <UNIT>        OSI_Interface_Definitions
--
-- <DESCRIPTION> This package exports some types used by other OSI packages to 
--               interface with C routines.  The types are the Ada 
--               representations of C types.
--
-- <HISTORY>
--
-- <ORIGIN>
-- <AUTHOR>      Gerardo A. Colon
-- <DATE>        06 September 1990
--
-- <COMPANY>     Science Applications International Corporation
-- <ADDRESS>     311 Park Place Boulevard, Suite 360
-- <ADDRESS>     Clearwater, Florida 34619
--
-- <REMARK>      Developed for the STARS program under task S40.
-- </ORIGIN>
--
-- </HISTORY>
--
-- <NOTES>       Dependencies =>
--                 ( Operating_System => None ,
--                   Compiler         => None ,
--                   Device           => None ) ;
--
-- </PROLOGUE>
--------------------------------------------------------------------------------

with System ;

pragma Page ;

--------------------------------------------------------------------------------
-- package OSI_Interface_Definitions (specification).
--------------------------------------------------------------------------------

package OSI_Interface_Definitions is

  subtype String_Pointer is System.Address ;
--
-- This type defines a reference to a String.  This type is compatible with
-- the C type char *.
--

  type Interface_Integer is range (-2**31) .. (2**31-1) ;
--
-- This type defines an integer which is compatible with a C int type.
--

  type Interface_Unsigned is range 0 .. (2**31-1) ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned.
--

  type Interface_Ulong is range 0 .. (2**31-1) ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned long.
--

  type Interface_Ushort is range 0 .. (2**16-1) ;
--
-- This type defines a non-negative integer which is compatible with the C
-- type unsigned short.
--

  type Interface_Long is range (-2**31) .. (2**31-1) ;
--
-- This type defines an integer which is compatible with the C type long.
--

  type Interface_Short is range (-2**16) .. (2**16-1) ;
--
-- This type defines an integer which is compatible with the C type long.
--

  type Integer_Pointer is access Interface_Integer ;
--
-- This type defines a reference to the type Interface_Integer.  This is 
-- necessary since C functions only take parameters of mode "in".
--

end OSI_Interface_Definitions ;

-- </ADA>
