-- <!DOCTYPE ADA>
-- <ADA>

--------------------------------------------------------------------------------
-- <PROLOGUE>
-- <UNIT>        OSI_Standard
--
-- <DESCRIPTION> This package defines the filename character set used by the 
--               OSI packages as well as some routines to manipulate the
--               character/strings.  The package also defines constants which
--               indicate the portable maximum length of a Filename and a 
--               Pathname.
--
-- <HISTORY>
--
-- <ORIGIN>
-- <AUTHOR>      Gerardo A. Colon
-- <DATE>        18 July 1990
--
-- <COMPANY>     Science Applications International Corporation
-- <ADDRESS>     311 Park Place Boulevard, Suite 360
-- <ADDRESS>     Clearwater, Florida 34619
--
-- <REMARK>      Developed under task S40 of the STARS program.
-- </ORIGIN>
--
-- </HISTORY>
--
-- <NOTES>       Dependencies =>
--                 ( Operating_System => None ,
--                   Compiler         => None ,
--                   Device           => None ) ;
--
-- </PROLOGUE>
--------------------------------------------------------------------------------

pragma Page ;

--------------------------------------------------------------------------------
-- package OSI_Standard (body).
--------------------------------------------------------------------------------

package body OSI_Standard is

  function To_OSI_String ( The_String : in String ) return OSI_String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        To_OSI_String
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
    The_OSI_String : OSI_String ( The_String'Range ) ;
  begin -- To_OSI_String 
    for Index in The_String'Range loop
      The_OSI_String ( Index ) := OSI_Character ( The_String ( Index ) ) ;
    end loop ;
    --
    return The_OSI_String ;
  end To_OSI_String ;

  function To_String ( The_OSI_String : in OSI_String ) return String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        To_String
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
    The_String : String ( The_OSI_String'Range ) ;
  begin -- To_String
    for Index in The_OSI_String'Range loop
      The_String ( Index ) := Character ( The_OSI_String ( Index ) ) ;
    end loop ;
    --
    return The_String ;
  end To_String ;

  function "&" ( Left  : String     ;
                 Right : OSI_String ) return OSI_String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        "&"
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
  begin -- "&" 
    return ( To_OSI_String ( Left ) & Right ) ;
  end "&" ;

  function "&" ( Left  : Character  ;
                 Right : OSI_String ) return OSI_String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        "&"
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
  begin -- "&" 
    return ( OSI_Character ( Left ) & Right ) ;
  end "&" ;

  function "&" ( Left  : OSI_String ;
                 Right : String     ) return OSI_String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        "&"
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
  begin -- "&" 
    return ( Left & To_OSI_String ( Right ) ) ;
  end "&" ;

  function "&" ( Left  : OSI_String ;
                 Right : Character  ) return OSI_String is
--------------------------------------------------------------------------------
-- <SUBPROGRAM>
-- <UNIT>        "&"
--
-- <DESCRIPTION> For a complete description of this subprogram see the
--               specification of this package.
--
-- <EXCEPTIONS>  For a complete description of the exceptions raised by this
--               subprogram see the specification of this package.
--
-- </SUBPROGRAM>
--------------------------------------------------------------------------------
  begin -- "&" 
    return ( Left & OSI_Character ( Right ) ) ;
  end "&" ;

end OSI_Standard ;

-- </ADA>
